import { createWriteStream } from "fs";
import { Readable } from "stream";

async function main() {
	//List out the emotes
	let emotes = [];
	let before = "";
	for (let i = 0; i < 50; i++) {
		const res = await fetch(`https://api.betterttv.net/3/emotes/shared/top?limit=100&before=${before}`).then(r => r.json());
		emotes = emotes.concat(res);
		before = res[res.length - 1].id;

		await new Promise(r => setTimeout(r, 100));
	}

	//Dedupe
	const nameIds = new Map();

	for (const item of emotes) {
		const name = item.emote.code;
		const id = item.emote.id;
	
		if (!nameIds.has(name)) {
			nameIds.set(name, id);
		}
	}

	//Write the emote list into a txt for convenience
	const emoteList = createWriteStream("emotes.txt");

	for (const name of nameIds.keys()) {
		emoteList.write(`- ${name}\n`);
	}

	emoteList.close();

	//Download the webps
	for (const [name, id] of nameIds) {
		console.log(`Downloading ${name}`);

		const url = `https://cdn.betterttv.net/emote/${id}/1x.webp`;
		const filename = `${name}.webp`;
		
		const res = await fetch(url);
		const file = createWriteStream(filename);

		Readable.fromWeb(res.body).pipe(file);

		await new Promise(r => setTimeout(r, 100));
	}
}

main().catch(err => console.error(err));
